'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _mongoose = require('mongoose');

var _mongoose2 = _interopRequireDefault(_mongoose);

var _fsReaddirRecursive = require('fs-readdir-recursive');

var _fsReaddirRecursive2 = _interopRequireDefault(_fsReaddirRecursive);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class MongooseSeed {
	constructor() {
		_mongoose2.default.Promise = global.Promise;
	}

	connect(db) {
		return new Promise((resolve, reject) => {
			_mongoose2.default.connect(db).then(() => {
				console.log('Connected to: ' + db);
				resolve();
			}).catch(error => {
				reject(error);
			});
		});
	}

	loadModels(modelsPath) {
		let files = (0, _fsReaddirRecursive2.default)(modelsPath);
		this.models = [];
		files.forEach(file => {
			if (~file.indexOf('.js')) {
				let model = require(modelsPath + '/' + file);
				this.models.push(model.default.modelName);
			}
		});
		console.log('Loaded models:', this.models);
	}

	populate(seedPath) {
		return new Promise((resolve, reject) => {
			let files = (0, _fsReaddirRecursive2.default)(seedPath);
			console.log('Loading data from: ', files);

			this.data = [];
			files.forEach(file => {
				if (~file.indexOf('.js') || ~file.indexOf('.json')) {
					this.data.push(require(seedPath + '/' + file));
				}
			});

			console.log('Populating collections: ', this.data.map(collection => collection.model));

			let promisses = [];
			this.data.forEach(collection => {
				console.log('Populating ' + collection.model + ' with ' + collection.data.length + ' entries');
				let Model = _mongoose2.default.model(collection.model);
				collection.data.forEach(entry => {
					promisses.push(this.create(Model, entry));
				});
			});
			Promise.all(promisses).then(() => {
				console.log('Population Done!');
				resolve();
			}).catch(error => {
				reject(error);
			});
		});
	}

	create(Model, entry) {
		return new Promise((resolve, reject) => {
			Model.create(entry, error => {
				if (!error) {
					resolve();
				} else {
					reject();
				}
			});
		});
	}

	clearAll(models) {
		return this.clearModels(this.models);
	}

	clearModels(models) {
		console.log('Clearing collections: ', models);
		return new Promise((resolve, reject) => {
			let promisses = [];
			models.forEach(modelName => {
				promisses.push(this.clearModel(modelName));
			});
			Promise.all(promisses).then(() => {
				resolve();
			}).catch(error => {
				reject(error);
			});
		});
	}

	clearModel(modelName) {
		return new Promise((resolve, reject) => {
			let Model = _mongoose2.default.model(modelName);
			Model.remove({}, error => {
				if (!error) {
					resolve();
				} else {
					reject();
				}
			});
		});
	}
}

exports.default = new MongooseSeed();